Provider networks are created by administrators. These networks map to an existing physical network in the data center.

Project networks are created by users. These networks are fully isolated and are project-specific.

An External network is set up by an administrator. If you want an instance to communicate outside of the data center, then attach a router between your Project network and the External network. You can use the Network Topology view to connect the router to the two networks.

A floating IP allows instances to be addressable from an external network. Floating IPs are not allocated to instances at creation time and may be assigned after the instance is created. To attach a floating IP, go to the Instances view and click the Actions menu to the right of an instance. Then, select the Associate Floating IP option and enter the necessary details.

Administrators set up the pool of floating IPs that are available to attach to instances.

#### Network characteristics

The subnet identifies a sub-section of a network. A subnet is specified in CIDR format. A typical CIDR format looks like `192.xxx.x.x/24`.

If a network is shared, then all users in the project can access the network.

When the Admin State for a network is set to Up, then the network is available for use. You can set the Admin State to Down if you are not ready for other users to access the network.

The status indicates whether the network has an active connection.